==> haskell-mmark-0.0.7.6-250-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mmark.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mmark
version:              0.0.7.6
visibility:           public
id:                   mmark-0.0.7.6-JEIOyGiJfyWLO9XTJQaPkB
key:                  mmark-0.0.7.6-JEIOyGiJfyWLO9XTJQaPkB
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mmark-md/mmark
synopsis:             Strict markdown processor for writers
description:          Strict markdown processor for writers.
category:             Text
abi:                  fcf27c795fff0a77b8a1cf9a732b27c2
exposed:              True
exposed-modules:      Text.MMark Text.MMark.Extension
hidden-modules:
    Text.MMark.Parser Text.MMark.Parser.Internal
    Text.MMark.Parser.Internal.Type Text.MMark.Render Text.MMark.Trans
    Text.MMark.Type Text.MMark.Util

import-dirs:          /usr/lib/ghc-9.4.8/site-local/mmark-0.0.7.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/mmark-0.0.7.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/mmark-0.0.7.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mmark
hs-libraries:         HSmmark-0.0.7.6-JEIOyGiJfyWLO9XTJQaPkB
depends:
    aeson-2.1.2.1-DzmMfEZgdOFRIaYChwLwW base-4.17.2.1
    case-insensitive-1.2.1.0-FZkso54i68UDZy9QWLkbnV containers-0.6.7
    deepseq-1.4.8.0 dlist-1.0-I6FB5Nlk17hG16fxQzZSEb
    email-validate-2.3.2.21-3OSgwl02xT13zvUbvAcFER
    foldl-1.4.18-6X3HQ97zt2eEdCMtdPqYLo
    hashable-1.4.4.0-Jc2uKL4S7Fl9QLNJZYpfiY
    html-entity-map-0.1.0.0-5QALSYtezZB5eqTZQXhVGE
    lucid-2.11.20230408-75EVo5DiRxh8Hwl8BHYJQN
    megaparsec-9.6.1-KkOPmPbRCEmCvB2XbKT9En
    microlens-0.4.13.1-BCmTOusOWAwKF1xfvNhRYd
    microlens-th-0.4.3.17-Vfga0HXPTS6SXD3NuXqZ3
    modern-uri-0.3.6.1-825m99sow9hGiAJe0XVgEZ mtl-2.2.2
    parser-combinators-1.3.0-11YwG5dPNej79xqbn9HKav text-2.0.2
    text-metrics-0.3.2-GpbdAVN3NA050ijK0xGwoJ
    unordered-containers-0.2.20-3jxCiK1Dn5HHqgJhQ3B9SH
    yaml-0.11.11.2-D13fcUitKz7KZZzPiF7Ifi

haddock-interfaces:   /usr/share/doc/haskell-mmark/html/mmark.haddock
haddock-html:         /usr/share/doc/haskell-mmark/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mmark-0.0.7.6-251-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mmark.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mmark
version:              0.0.7.6
visibility:           public
id:                   mmark-0.0.7.6-8Tc4wis6btb8Oa3CVb47ko
key:                  mmark-0.0.7.6-8Tc4wis6btb8Oa3CVb47ko
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mmark-md/mmark
synopsis:             Strict markdown processor for writers
description:          Strict markdown processor for writers.
category:             Text
abi:                  1f2b7bed18d2e8a65693c23b77f8324b
exposed:              True
exposed-modules:      Text.MMark Text.MMark.Extension
hidden-modules:
    Text.MMark.Parser Text.MMark.Parser.Internal
    Text.MMark.Parser.Internal.Type Text.MMark.Render Text.MMark.Trans
    Text.MMark.Type Text.MMark.Util

import-dirs:          /usr/lib/ghc-9.4.8/site-local/mmark-0.0.7.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/mmark-0.0.7.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/mmark-0.0.7.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mmark
hs-libraries:         HSmmark-0.0.7.6-8Tc4wis6btb8Oa3CVb47ko
depends:
    aeson-2.1.2.1-9BF5sjMs3G4H72EdbKHz4V base-4.17.2.1
    case-insensitive-1.2.1.0-FZkso54i68UDZy9QWLkbnV containers-0.6.7
    deepseq-1.4.8.0 dlist-1.0-I6FB5Nlk17hG16fxQzZSEb
    email-validate-2.3.2.21-3OSgwl02xT13zvUbvAcFER
    foldl-1.4.18-G0kHslXJCilDi7hBYPkzrw
    hashable-1.4.4.0-Jc2uKL4S7Fl9QLNJZYpfiY
    html-entity-map-0.1.0.0-10EK4pBYiMu1UrZyyzNQOM
    lucid-2.11.20230408-AnnjWF7cma7FnzrdnD8kRa
    megaparsec-9.6.1-KkOPmPbRCEmCvB2XbKT9En
    microlens-0.4.13.1-BCmTOusOWAwKF1xfvNhRYd
    microlens-th-0.4.3.17-Vfga0HXPTS6SXD3NuXqZ3
    modern-uri-0.3.6.1-JebwkzGI3xvLF7k9ivrgVB mtl-2.2.2
    parser-combinators-1.3.0-11YwG5dPNej79xqbn9HKav text-2.0.2
    text-metrics-0.3.2-GpbdAVN3NA050ijK0xGwoJ
    unordered-containers-0.2.20-L3M6eILO3KM5ipeNJik2xY
    yaml-0.11.11.2-6v6Bs7hsx93E2WTArMECOh

haddock-interfaces:   /usr/share/doc/haskell-mmark/html/mmark.haddock
haddock-html:         /usr/share/doc/haskell-mmark/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
